summaryrefslogtreecommitdiffstats
path: root/include/asm-alpha/pci.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/asm-alpha/pci.h')
-rw-r--r--include/asm-alpha/pci.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/asm-alpha/pci.h b/include/asm-alpha/pci.h
index 85923e999..781a4882b 100644
--- a/include/asm-alpha/pci.h
+++ b/include/asm-alpha/pci.h
@@ -16,10 +16,10 @@ struct pci_bus;
struct resource;
struct pci_iommu_arena;
-/* A controler. Used to manage multiple PCI busses. */
+/* A controller. Used to manage multiple PCI busses. */
-struct pci_controler {
- struct pci_controler *next;
+struct pci_controller {
+ struct pci_controller *next;
struct pci_bus *bus;
struct resource *io_space;
struct resource *mem_space;